{image file-path="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3b/UDP_encapsulation.svg/800px-UDP_encapsulation.svg.png" caption="true" alt="UDP Encapsulation"}

So it goes...

{image end}

TODO: Upload this image to field guide, and link back to svg page.
